docs.rs failed to build shecret-0.2.0
Please check the build logs for more information.
See Builds for ideas on how to fix a failed build, or Metadata for how to configure docs.rs builds.
If you believe this is docs.rs' fault, open an issue.
Please check the build logs for more information.
See Builds for ideas on how to fix a failed build, or Metadata for how to configure docs.rs builds.
If you believe this is docs.rs' fault, open an issue.
Visit the last successful build:
shecret-0.1.6
Shecret

1. Description
Shecret is a CLI SSH/SFTP client
Once the connection is selected, the full SSH/SFTP command will be stored on your clipboard, then just paste it on the terminal!
It also issues SSH commands to multiple servers at once (sort of what Ansible does)
2. Features

3. Instalation
3.1 Cargo
cargo install shecret
3.2 Linux binary
Download this file and make sure you've granted executable permissions to it
./shecret